# ../scripts/custom/gg_give/gg_give_config.py

# ============================================================================
# >> IMPORTS
# ============================================================================
# EventScripts Imports
import es
import cfglib

# GunGame Imports
from gungame51.core.cfg import generate_header

# ============================================================================
# >> GLOBAL VARIABLES
# ============================================================================
config = cfglib.AddonCFG('%s/cfg/' % es.ServerVar('eventscripts_gamedir') +
    'gungame51/custom_addon_configs/gg_give.cfg')

# ============================================================================
# >> LOAD & UNLOAD
# ============================================================================
def load():
    generate_header(config)

    # gg_give
    config.text('')
    config.text('='*76)
    config.text('>> GG GIVE - ENABLE or DISABLE FAST RELOAD')
    config.text('='*76)
    config.text('Description:')
    config.text('   This variable controls whether this addon will load or not. ')
    config.text('Options:')
    config.text('   0 = (Disabled) Off.')
    config.text('   1 = (Enabled) On.')
    config.text('Default Value: 1')
    config.cvar('gg_give', 1, 'Enables/Disables ' +
                'gg_give.').addFlag('notify')
    config.text('')
    config.text('')


    # gg_give_command
    config.text('='*76)
    config.text('>> PLAYER COMMAND')
    config.text('='*76)
    config.text('Description:')
    config.text('   Fast reload command to register.')
    config.text('Notes:')
    config.text('   * You can change this to whatever you want, however you ' +
		'should make sure ')
    config.text('     that whatever you change this to is not already ' +
		'registered.')
    config.text('Examples:')
    config.text('   gg_give_command "!give"')
    config.text('   gg_give_command "!gun"')
    config.text('Default Value: "!give"')
    config.cvar('gg_give_command', "!give",
                            'Player say command for GunGame\'s fast reload.')
    config.text('')
    config.text('')


    # gg_give_delay_usage
    config.text('='*76)
    config.text('>> USAGE DELAY')
    config.text('='*76)
    config.text('Description:')
    config.text('   This variable controls how often player may use fast reload.')
    config.text('   Set to 0 to disable delay.')
    config.text('Options:')
    config.text('   0 = (Disabled) No delay.')
    config.text('   # = (Enabled) Delay with # amount of seconds.')
    config.text('Default Value: 3')
    config.cvar('gg_give_delay_usage', 3, 'Controls GunGame\'s fast reload delay.')
    config.text('')
    config.text('')


    # gg_give_per_round
    config.text('='*76)
    config.text('>> PER ROUND USAGE LIMIT')
    config.text('='*76)
    config.text('Description:')
    config.text('   This variable controls how many times player may use fast ' +
                    'reload per')
    config.text('   round. This value should be less than gg_give_per_map, or')
    config.text('   set it to 0 to disable round limit.')
    config.text('Options:')
    config.text('   0 = (Disabled) Off.')
    config.text('   # = (Enabled) On with # of reloads per round.')
    config.text('Default Value: 15')
    config.cvar('gg_give_per_round', 15, 'Controls GunGame\'s fast reloads per round.')
    config.text('')
    config.text('')


    # gg_give_per_map
    config.text('='*76)
    config.text('>> PER MAP USAGE LIMIT')
    config.text('='*76)
    config.text('Description:')
    config.text('   This variable controls how many times player may use fast ' +
                    'reload per map.')
    config.text('   This value should be greater than gg_give_per_round, or set')
    config.text('   it to 0 to disable map limit.')
    config.text('Options:')
    config.text('   0 = (Disabled) Off.')
    config.text('   # = (Enabled) On with # of reloads per map.')
    config.text('Default Value: 200')
    config.cvar('gg_give_per_map', 200, 'Controls GunGame\'s fast reloads per map.')
    config.text('')
    config.text('')


    # gg_give_show_stats
    config.text('='*76)
    config.text('>> DISPLAY FAST RELOADS REMAINING')
    config.text('='*76)
    config.text('Description:')
    config.text('   This variable controls whether fast reloads remaining is ' +
                    'displayed.')
    config.text('   If you have per round or map limit enabled then you should ' +
                    'enable') 
    config.text('   this or players will not be aware of set limits.')
    config.text('Options:')
    config.text('   0 = (Disabled) Off.')
    config.text('   1 = (Enabled) On.')
    config.text('Default Value: 1')
    config.cvar('gg_give_show_stats', 1, 'Display fast reload status.')
    config.text('')
    config.text('')


    # gg_give_warmup_round
    config.text('='*76)
    config.text('>> FAST RELOAD IN WARMUP ROUND')
    config.text('='*76)
    config.text('Description:')
    config.text('   This variable controls whether fast reload is enabled or disabled durring')
    config.text('   warmup round.')
    config.text('Options:')
    config.text('   0 = (Disabled) Off.')
    config.text('   1 = (Enabled) On.')
    config.text('Default Value: 0')
    config.cvar('gg_give_warmup_round', 0, 'Enables/Disables fast reload durring warmup round.')
    config.text('')
    config.text('')


    # gg_give_disp_msgs_in_hud
    config.text('='*76)
    config.text('>> DISPLAY ALL FAST RELOAD MESSAGES IN HUD')
    config.text('='*76)
    config.text('Description:')
    config.text('   This variable controls whether or not all fast reload messages will be')
    config.text('   displayed in HUD. If disabled, all fast reload messages will be displayed')
    config.text('   in chat.')
    config.text('Options:')
    config.text('   0 = (Disabled) Off.')
    config.text('   1 = (Enabled) On.')
    config.text('Default Value: 1')
    config.cvar('gg_give_disp_msgs_in_hud', 1, 'Displays all fast reload messages in HUD.')
    config.text('')
    config.text('')


    # gg_give_weapon_exceptions
    config.text('='*76)
    config.text('>> WEAPON EXCEPTION LIST')
    config.text('='*76)
    config.text('Description:')
    config.text('   Disable fast reload while on these weapons.')
    config.text('Notes:')
    config.text('   * This is a comma , seperated list.')
    config.text('Examples:')
    config.text('   gg_give_weapon_exceptions "knife,hegrenade,glock"')
    config.text('   gg_give_weapon_exceptions "glock"')
    config.text('Default Value: "knife,hegrenade"')
    config.cvar('gg_give_weapon_exceptions', "knife,hegrenade",
                            'Disable fast reload while on these weapons.')
    config.text('')
    config.text('')

    config.write()
    es.dbgmsg(0, '\tgg_give.cfg')

def unload():
    global config

    # Remove the "notify" flags as set by addFlag('notify')
    for cvar in config.getCvars().keys():
        es.flags('remove', 'notify', cvar)

    # Delete the cfglib.AddonCFG instance
    del config
